package com.ruoyi.system.service.impl;

import com.ruoyi.common.core.domain.entity.MusicRecommend;
import com.ruoyi.system.mapper.MusicRecommendMapper;
import com.ruoyi.system.service.IMusicRecommendService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 【请填写功能名称】Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-07-15
 */
@Service
public class MusicRecommendServiceImpl implements IMusicRecommendService 
{
    @Autowired
    private MusicRecommendMapper musicRecommendMapper;


    /**
     * 查询【请填写功能名称】
     * 
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    @Override
    public MusicRecommend selectMusicRecommendById(String id)
    {
        return musicRecommendMapper.selectMusicRecommendById(id);
    }

    /**
     * 查询【请填写功能名称】列表
     * 
     * @param musicRecommend 【请填写功能名称】
     * @return 【请填写功能名称】
     */
    @Override
    public List<MusicRecommend> selectMusicRecommendList(MusicRecommend musicRecommend)
    {
        return musicRecommendMapper.selectMusicRecommendList(musicRecommend);
    }

    /**
     * 新增【请填写功能名称】
     * 
     * @param musicRecommend 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int insertMusicRecommend(MusicRecommend musicRecommend)
    {
        return musicRecommendMapper.insertMusicRecommend(musicRecommend);
    }

    /**
     * 修改【请填写功能名称】
     * 
     * @param musicRecommend 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int updateMusicRecommend(MusicRecommend musicRecommend)
    {
        return musicRecommendMapper.updateMusicRecommend(musicRecommend);
    }

    /**
     * 批量删除【请填写功能名称】
     * 
     * @param ids 需要删除的【请填写功能名称】主键
     * @return 结果
     */
    @Override
    public int deleteMusicRecommendByIds(Long[] ids)
    {
        // 删除关联数据
        return musicRecommendMapper.deleteMusicRecommendByIds(ids);
    }

    /**
     * 删除【请填写功能名称】信息
     * 
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
    @Override
    public int deleteMusicRecommendById(String id)
    {
        return musicRecommendMapper.deleteMusicRecommendById(id);
    }
}
